pub struct HighlightState<'a> { /* private fields */ }Expand description
State for streaming syntax highlighting.
This maintains the parse state across lines to correctly handle multi-line tokens like block comments and strings.
Implementations
Sourceimpl<'a> HighlightState<'a>
impl<'a> HighlightState<'a>
Sourcepub fn new(syntax: &'a SyntaxReference, theme: &'a Theme) -> Self
pub fn new(syntax: &'a SyntaxReference, theme: &'a Theme) -> Self
Create a new highlight state for a syntax and theme.